pymyo
=====

[![PyPI](https://img.shields.io/pypi/v/pymyo)](https://pypi.org/project/pymyo/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pymyo)](https://pypi.org/project/pymyo/)
[![GitHub](https://img.shields.io/github/license/Crimson-Crow/pymyo)]((https://github.com/Crimson-Crow/pymyo/blob/main/LICENSE.txt))

Description
-----------

`pymyo` is a platform-agnostic Python module that allows you to configure or retrieve data from a Thalmic Labs Myo armband through BLE **without** the need to have the Myo SDK installed or the need to use the original dongle.

WIP
---
Documentation coming soon! Docstrings are provided for the time being.

Issue tracker
-------------

Please report any bugs and enhancement ideas using the [issue tracker](https://github.com/Crimson-Crow/pymyo/issues).

Acknowledgments
---------------

The development of this project was instigated and made possible by professor François Nougarou.

License
-------

`pymyo` is licensed under the terms of the [MIT License](https://opensource.org/licenses/MIT) (see [LICENSE.txt](https://github.com/Crimson-Crow/pymyo/blob/main/LICENSE.txt) for more information).
